@@ -494,11 +494,7 @@ bool KExiv2::setExifTagData(const char* exifTagName, const QByteArray& data, boo
 bool KExiv2::setExifTagVariant(const char* exifTagName, const QVariant& val,
                                bool rationalWantSmallDenominator, bool setProgramName) const
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     switch (val.metaType().id())
-#else
-    switch (val.type())
-#endif
     {
         case QMetaType::Int:
         case QMetaType::UInt:
@@ -579,11 +575,7 @@ QString KExiv2::createExifUserStringFromValue(const char* exifTagName, const QVa
         Exiv2::ExifKey key(exifTagName);
         Exiv2::Exifdatum datum(key);
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         switch (val.metaType().id())
-#else
-        switch (val.type())
-#endif
         {
             case QMetaType::Int:
             case QMetaType::Bool:
@@ -750,22 +742,14 @@ QVariant KExiv2::getExifTagVariant(const char* exifTagName, bool rationalAsListO
                         return QVariant((int)it->toLong(component));
 #endif
                     else
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                         return QVariant(QMetaType(QMetaType::Int));
-#else
-                        return QVariant(QVariant::Int);
-#endif
                 case Exiv2::unsignedRational:
                 case Exiv2::signedRational:
 
                     if (rationalAsListOfInts)
                     {
                         if (it->count() <= component)
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                             return QVariant(QMetaType(QMetaType::QVariantList));
-#else
-                            return QVariant(QVariant::List);
-#endif
 
                         QList<QVariant> list;
                         list << (*it).toRational(component).first;
@@ -776,22 +760,14 @@ QVariant KExiv2::getExifTagVariant(const char* exifTagName, bool rationalAsListO
                     else
                     {
                         if (it->count() <= component)
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                             return QVariant(QMetaType(QMetaType::Double));
-#else
-                            return QVariant(QVariant::Double);
-#endif
 
                         // prefer double precision
                         double num = (*it).toRational(component).first;
                         double den = (*it).toRational(component).second;
 
                         if (den == 0.0)
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                             return QVariant(QMetaType(QMetaType::Double));
-#else
-                            return QVariant(QVariant::Double);
-#endif
 
                         return QVariant(num / den);
                     }
@@ -1006,10 +982,8 @@ bool KExiv2::setTiffThumbnail(const QImage& thumbImage, bool setProgramName) con
         {
 #if EXIV2_TEST_VERSION(0,28,0)
             throw Exiv2::Error(Exiv2::ErrorCode::kerErrorMessage, "Exif.Image.NewSubfileType missing or not set as main image");
-#elif EXIV2_TEST_VERSION(0,27,0)
-            throw Exiv2::Error(Exiv2::kerErrorMessage, "Exif.Image.NewSubfileType missing or not set as main image");
 #else
-            throw Exiv2::Error(1, "Exif.Image.NewSubfileType missing or not set as main image");
+            throw Exiv2::Error(Exiv2::kerErrorMessage, "Exif.Image.NewSubfileType missing or not set as main image");
 #endif
         }
 
